@@ -19,6 +19,8 @@ Both relative and absolute path available.
 ## Manual
 j / <Down>         :Go down.
 k / <Up>           :Go up.
+<C-d>              :Go down 1/2 page.
+<C-u>>             :Go up 1/2 page.
 h / <Left>         :Go to the parent directory if exists.
 l / <Right> / <CR> :Open item or change directory.
 gg                 :Go to the top.
@@ -49,6 +51,7 @@ V                  :Switch to the linewise visual mode.
   - "ad            :In the visual mode, delete and yank items to register a.
   - "Ay            :In the visual mode, append items to register a.
   - "Ad            :In the visual mode, delete and append items to register a.
+  - c              :Rename selected items in default editor.
 u                  :Undo put/delete/rename.
 <C-r>              :Redo put/delete/rename.
 v                  :Toggle whether to show the preview.
